summaryrefslogtreecommitdiffstats
path: root/src/usr/diag/prdf/plat/mem/prdfMemTps.H
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/diag/prdf/plat/mem/prdfMemTps.H')
-rw-r--r--src/usr/diag/prdf/plat/mem/prdfMemTps.H40
1 files changed, 19 insertions, 21 deletions
diff --git a/src/usr/diag/prdf/plat/mem/prdfMemTps.H b/src/usr/diag/prdf/plat/mem/prdfMemTps.H
index 577de3d6a..6facb1877 100644
--- a/src/usr/diag/prdf/plat/mem/prdfMemTps.H
+++ b/src/usr/diag/prdf/plat/mem/prdfMemTps.H
@@ -99,37 +99,35 @@ class TpsEvent : public TdEntry
/**
* @brief Analyzes the counts that summarize the symbol CE counts.
* @param i_badDqCount Number of nibbles with a bad DQ
* @param i_badChipCount Number of nibbles with a bad Chip
* @param i_nonZeroSumCount Number of nibbles under threshold with a
* non-zero sum
* @param i_singleSymCount Number of nibbles under threshold with a
* single symbol count greater than one
* @param i_symList Vector of all symbols with counts > 0.
* @param io_sc The step code data struct.
* @return Non-SUCCESS if an internal function fails, SUCCESS otherwise.
*/
uint32_t analyzeCeSymbolCounts( CeCount i_badDqCount,
- CeCount i_badChipCount, CeCount i_nonZeroSumCount,
- CeCount i_singleSymCount, MemUtils::MaintSymbols i_symList,
- STEP_CODE_DATA_STRUCT & io_sc );
+ CeCount i_badChipCount, CeCount i_sumAboveOneCount,
+ CeCount i_singleSymCount, STEP_CODE_DATA_STRUCT & io_sc );
/**
* @brief Gets the counts that summarize the symbol CE counts.
* @param io_badDqCount Number of nibbles with a bad DQ
* @param io_badChipCount Number of nibbles with a bad Chip
* @param io_nonZeroSumCount Number of nibbles under threshold with a
* non-zero sum
* @param io_singleSymCount Number of nibbles under threshold with a
* single symbol count greater than one
* @param o_symList Vector of all symbols with CE counts > 0.
* @param io_sc The step code data struct.
* @return Non-SUCCESS if an internal function fails, SUCCESS otherwise.
*/
uint32_t getSymbolCeCounts( CeCount & io_badDqCount,
- CeCount & io_badChipCount, CeCount & io_nonZeroSumCount,
- CeCount & io_singleSymCount, MemUtils::MaintSymbols & o_symList,
- STEP_CODE_DATA_STRUCT & io_sc );
+ CeCount & io_badChipCount, CeCount & io_sumAboveOneCount,
+ CeCount & io_singleSymCount, STEP_CODE_DATA_STRUCT & io_sc );
/**
* @brief Does isolation for CE attentions.
OpenPOWER on IntegriCloud
@@ -99,37 +99,35 @@ class TpsEvent : public TdEntry
/**
* @brief Analyzes the counts that summarize the symbol CE counts.
- * @param i_badDqCount Number of nibbles with a bad DQ
- * @param i_badChipCount Number of nibbles with a bad Chip
- * @param i_nonZeroSumCount Number of nibbles under threshold with a
- * non-zero sum
- * @param i_singleSymCount Number of nibbles under threshold with a
- * single symbol count greater than one
- * @param i_symList Vector of all symbols with counts > 0.
+ * @param i_badDqCount Number of nibbles with a bad DQ
+ * @param i_badChipCount Number of nibbles with a bad Chip
+ * @param i_sumAboveOneCount Number of nibbles under threshold with a
+ * sum greater than 1
+ * @param i_singleSymCount Number of nibbles under threshold with only
+ * a single symbol with a non-zero count, and
+ * that count is > 1
* @param io_sc The step code data struct.
* @return Non-SUCCESS if an internal function fails, SUCCESS otherwise.
@@ -99,37 +99,35 @@ class TpsEvent : public TdEntry
/**
* @brief Gets the counts that summarize the symbol CE counts.
- * @param io_badDqCount Number of nibbles with a bad DQ
- * @param io_badChipCount Number of nibbles with a bad Chip
- * @param io_nonZeroSumCount Number of nibbles under threshold with a
- * non-zero sum
- * @param io_singleSymCount Number of nibbles under threshold with a
- * single symbol count greater than one
- * @param o_symList Vector of all symbols with CE counts > 0.
- * @param io_sc The step code data struct.
+ * @param io_badDqCount Number of nibbles with a bad DQ
+ * @param io_badChipCount Number of nibbles with a bad Chip
+ * @param io_sumAboveOneCount Number of nibbles under threshold with a
+ * sum greater than 1
+ * @param io_singleSymCount Number of nibbles under threshold with only
+ * a single symbol with a non-zero count, and
+ * that count is > 1
+ * @param io_sc The step code data struct.
* @return Non-SUCCESS if an internal function fails, SUCCESS otherwise.
*/